# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sefazetllib',
 'sefazetllib.config',
 'sefazetllib.etl',
 'sefazetllib.extract',
 'sefazetllib.factory',
 'sefazetllib.factory.platform',
 'sefazetllib.factory.platform.database',
 'sefazetllib.factory.platform.dataframe',
 'sefazetllib.load',
 'sefazetllib.transform',
 'sefazetllib.utils',
 'sefazetllib.utils.key',
 'sefazetllib.utils.partition',
 'sefazetllib.validate']

package_data = \
{'': ['*']}

install_requires = \
['pandas>=1.4,<2.0', 'pyarrow>=6.0,<7.0', 'pyspark>=3.0,<4.0']

setup_kwargs = {
    'name': 'sefazetllib',
    'version': '0.1.0',
    'description': 'sefazetllib is a library that provides a simplified and abstracted way to construct ETL/ELT pipelines.',
    'long_description': '# sefazetllib\n\n[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)\n[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json)](https://github.com/charliermarsh/ruff)\n[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\n---\n\n**Documentation**: [https://main.daseasp5gkpi2.amplifyapp.com/](https://main.daseasp5gkpi2.amplifyapp.com/)\n\n**Source code**: [AWS CodeCommit](https://sa-east-1.console.aws.amazon.com/codesuite/codecommit/repositories/jobs-lib-sefaz-ce/browse?region=sa-east-1)\n\n---\n\n**sefazetllib** is a library that provides a simplified and abstracted way to construct ETL/ELT pipelines.\n\n## Features\n\n- Easy to use and understand library for constructing ETL/ELT pipelines.\n- Compatibility with popular data processing frameworks, such as [pandas](https://pandas.pydata.org/) and [PySpark](https://spark.apache.org/).\n- Support for file formats such as CSV and Parquet.\n- Provides the ability to extract, transform and load data with customizable configurations.\n\n## Requirements\n\n**sefazetllib** requires the following to run:\n\n- [Python](https://www.python.org/) 3.8+\n- [pandas](https://pandas.pydata.org/) 1.4+\n- [PyArrow](https://arrow.apache.org/) 6.0+\n- [PySpark](https://spark.apache.org/) 3.0+\n\n## Installation\n\nFirst, use [AWS CLI](https://aws.amazon.com/cli/) to get the necessary credentials:\n\n```bash\nREGION="sa-east-1"\nACCOUNT_ID="999424586482"\nSECRET_NAME="dev/servico-sefaz-ce-9u8PW2"\n\nUSERNAME=$(aws secretsmanager get-secret-value --region $REGION --secret-id arn:aws:secretsmanager:$REGION:$ACCOUNT_ID:secret:$SECRET_NAME | grep SecretString | cut -d \'\\\' -f 4 | cut -d \'"\' -f 2 | cut -d \' \' -f 2)\nPASSWORD=$(aws secretsmanager get-secret-value --region $REGION --secret-id arn:aws:secretsmanager:$REGION:$ACCOUNT_ID:secret:$SECRET_NAME | grep SecretString | cut -d \'\\\' -f 8 | cut -d \'"\' -f 2 | cut -d \' \' -f 2)\n```\n\nThen install **sefazetllib** using [pip](https://pip.pypa.io/en/stable/):\n\n```bash\npip install git+https://${USERNAME}:${PASSWORD}@git-codecommit.sa-east-1.amazonaws.com/v1/repos/jobs-lib-sefaz-ce.git\n```\n\n## Usage\n\nHere is an example of how to use the **sefazetllib**:\n\n```Python\nfrom typing import Tuple\n\nfrom pandas import DataFrame\n\nfrom sefazetllib import Builder\nfrom sefazetllib.etl import ETL\nfrom sefazetllib.extract import ExtractLocal\nfrom sefazetllib.factory.platform import PlatformFactory\nfrom sefazetllib.load import LoadLocal\nfrom sefazetllib.transform import Transform\nfrom sefazetllib.utils.key import SurrogateKey\n\n\n@Builder\nclass TestingDataFrame(Transform):\n    def execute(self) -> Tuple[str, DataFrame]:\n        return (\n            "dataframe",\n            DataFrame(\n                [["tom", 10], ["nick", 15], ["juli", 14]], columns=["Name", "Age"]\n            ),\n        )\n\n\n(\n    ETL()\n    .setPlatform(PlatformFactory("Pandas").create(name="pandas_platform"))\n    .transform(TestingDataFrame)\n    .load(\n        LoadLocal()\n        .setFileFormat("parquet")\n        .setEntity("load_test")\n        .setMode("overwrite")\n        .setReference("dataframe")\n        .setDuplicates(True)\n        .setKey(SurrogateKey().setColumns(["Name", "Age"]).setDistribute(False))\n    )\n    .extract(\n        ExtractLocal()\n        .setFileFormat("parquet")\n        .setUrl("load_test.parquet")\n        .setReference("extract_test")\n    )\n)\n```\n\n## Testing\n\nTo run the unit tests, run the following command:\n\n```bash\npy -m unittest tests/main.py -v\n```\n\n### Status\n\n| Environment      | Status                                                                                                                                                                                                                                                                                                                 |\n|------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|\n| Feature to Homologation    | ![feature-homologation](https://codebuild.sa-east-1.amazonaws.com/badges?uuid=eyJlbmNyeXB0ZWREYXRhIjoiYzRJb1JnV2FyS0UxZkVwMk5rNXpCNklFV3BBYVBEMWtLYnMvazVSWDA4WkQvK2twdXMrUmZ5bGRKdUFiU2tEUFF1dkxBRHYrVkdCMDRRNndzV3hKdG13PSIsIml2UGFyYW1ldGVyU3BlYyI6IlFBRmJaZkRpemtwbHVqT0MiLCJtYXRlcmlhbFNldFNlcmlhbCI6MX0%3D&branch=main)    |\n| Homologation to Production | ![homologation-production](https://codebuild.sa-east-1.amazonaws.com/badges?uuid=eyJlbmNyeXB0ZWREYXRhIjoiekhWVXpwajRjVjg4TUg2d0RrUy9BOGhNYTFObTZBKzRTMTZscmtaTzdoTmVWTDdaR0xZbjMrOTZVT3ZqTU40eFFEYzJGZkFtUzNSRTl5b2x5ajZOMXlBPSIsIml2UGFyYW1ldGVyU3BlYyI6ImUxajQxOG50TkZkWHh2T2oiLCJtYXRlcmlhbFNldFNlcmlhbCI6MX0%3D&branch=main) |\n\n## License\n\n**sefazetllib** is released under the [Apache-2.0](/LICENSE).\n',
    'author': 'Felipe Gochi',
    'author_email': 'felipe.gochi@elogroup.com.br',
    'maintainer': 'Bruno Santos',
    'maintainer_email': 'bruno.santos@elogroup.com.br',
    'url': 'https://sa-east-1.console.aws.amazon.com/codesuite/codecommit/repositories/jobs-lib-sefaz-ce/browse?region=sa-east-1',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
